<?php 

namespace Management\Services;

use Doctrine\ORM\EntityManager;
use Management\Util;

class ManageDashboardService {

    public function __construct(EntityManager $entityManager) {
        $this->entityManager = $entityManager;
    }

	public function getVendasMensais($CDFILIAL,$NRORG) {
		$params = array(
			':CDFILIAL' => $CDFILIAL,
			':NRORG' => $NRORG		
		);
		return $this->entityManager->getConnection()->fetchAll(Util\Query::GET_VENDAS_MENSAIS, $params);
	}
	
	public function getObjetivoVendaDiaAlt($CDFILIAL,$NRORG,$CDOBJANO,$NRDIASEMANA,$DTALT,$CDOBJMES) {
		$params = array(
			':CDFILIAL'		=>	$CDFILIAL,
			':NRORG'		=>	$NRORG,
			':CDOBJANO'		=>	$CDOBJANO,
			':NRDIASEMANA'	=>	$NRDIASEMANA,
			':DTALT'		=>	$DTALT,
			':CDOBJMES'		=>	$CDOBJMES
		);
		
		return $this->entityManager->getConnection()->fetchAll(Util\Query::GET_OBJETIVO_VENDA_DIA_ALT, $params);
	}
	
	public function getObjetivoVendaDia($CDFILIAL,$NRORG,$CDOBJANO,$CDOBJDIA,$CDOBJMES) {
		$params = array(
			':CDFILIAL'		=>	$CDFILIAL,
			':NRORG'		=>	$NRORG,
			':CDOBJANO'		=>	$CDOBJANO,
			':CDOBJDIA'		=>	$CDOBJDIA,
			':CDOBJMES'		=>	$CDOBJMES
		);
		
		return $this->entityManager->getConnection()->fetchAll(Util\Query::GET_OBJETIVO_VENDA_DIA, $params);
	}
	
	public function getObjetivoVendaMes($CDFILIAL,$NRORG,$CDOBJANO,$CDOBJMES) {
		$params = array(
			':CDFILIAL'		=>	$CDFILIAL,
			':NRORG'		=>	$NRORG,
			':CDOBJANO'		=>	$CDOBJANO,
			':CDOBJMES'		=>	$CDOBJMES
		);
		
		return $this->entityManager->getConnection()->fetchAll(Util\Query::GET_OBJETIVO_VENDA_MES, $params);
	}
	
	public function getVendasDiarias($CDFILIAL, $DTENTRVENDA, $NRORG) {
		$params = array(
			':CDFILIAL'		=>	$CDFILIAL,
			':DTENTRVENDA'	=>	$DTENTRVENDA,
			':NRORG'		=>	$NRORG
		);
		
		$vndsConc = $this->entityManager->getConnection()->fetchAll(Util\Query::GET_VENDAS_DIARIAS_CONCLUIDAS, $params);
		$vndsCanc = $this->entityManager->getConnection()->fetchAll(Util\Query::GET_VENDAS_DIARIAS_CANCELADAS, $params);
	
		return array_merge($vndsConc[0], $vndsCanc[0]);
	}
	
	public function getProdutosMaisVendidos($CDFILIAL, $DTENTRVENDA, $NRORG) {
		$params = array(
			':CDFILIAL'		=>	$CDFILIAL,
			':DTENTRVENDA'	=>	$DTENTRVENDA,
			':NRORG'		=>	$NRORG
		);
		return $this->entityManager->getConnection()->fetchAll(Util\Query::GET_PRODUTOS_MAIS_VENDIDOS, $params);
	}
	
	public function findDivergenciasConciliacao ($NRORG) {
		$params = array (
			':NRORG'	=> $NRORG
		);
		
		return $this->entityManager->getConnection()->fetchAll(Util\Query::COUNT_DIVERGENCIAS_CONCILIACO, $params);
	}
	
	public function findFiliaisDoOperador ($CDOPERADOR, $NRORG) {
		$params = array (
			':NRORG'		=> $NRORG,
			':CDOPERADOR'	=> $CDOPERADOR
		);
		
		return $this->entityManager->getConnection()->fetchAll(Util\Query::GET_FILIAIS_OPERADOR, $params);
	}
	
	public function findConsolidacaoVendaPendente ($NRORG, $CDOPERADOR, $CDFILIAL) {
		$params = array (
			':NRORG'	=> $NRORG,
			':CDOPERADOR'	=> $CDOPERADOR,
			':DTINI'	=> null,
			':DTFIN'	=> null,
			':TODASNF'   => 'S'
		);
		
		$result = null; 
		
		if($CDFILIAL === false) {
			$result = $this->entityManager->getConnection()->fetchAll(Util\Query::GET_CONSOLIDACAO_VENDA_PENDENTE, $params);
		} else {
			$params['CDFILIAL'] = $CDFILIAL;
			
			$result = $this->entityManager->getConnection()->fetchAll(Util\Query::GR_GET_CONSOLIDACAO_VENDA_PENDENTE, $params);
		}
		
		return $result;
	}
	
	public function findFechamentoCupomPendente ($NRORG, $CDOPERADOR, $CDFILIAL) {
		$params = array (
			':NRORG'	=> $NRORG,
			':DTINI'	=> null,
			':DTFIN'	=> null,
			':CDOPERADOR'	=> $CDOPERADOR
		);
		
		$result = null; 
		
		if($CDFILIAL === false) {
			$result = $this->entityManager->getConnection()->fetchAll(Util\Query::GET_FECHAMENTO_CUPOM_PENDENTE, $params);
		} else {
			$params['CDFILIAL'] = $CDFILIAL;
			
			$result = $this->entityManager->getConnection()->fetchAll(Util\Query::GR_GET_FECHAMENTO_CUPOM_PENDENTE, $params);
		}
		
		return $result;
	}
	
	public function findFechamentoCaixaPendente ($NRORG, $CDOPERADOR, $CDFILIAL) {
		$params = array (
			':NRORG'	=> $NRORG,
			':DTINI'	=> null,
			':DTFIN'	=> null,
			':CDOPERADOR'	=> $CDOPERADOR
		);
		
		$result = null; 
		
		if($CDFILIAL === false) {
			$result = $this->entityManager->getConnection()->fetchAll(Util\Query::GET_FECHAMENTO_CAIXA_PENDENTE, $params);
		} else {
			$params['CDFILIAL'] = $CDFILIAL;
			
			$result = $this->entityManager->getConnection()->fetchAll(Util\Query::GR_GET_FECHAMENTO_CAIXA_PENDENTE, $params);
		}
		
		return $result;
	}
	
	public function unidadeBloq($conditions){
		$params = array(
        		":NRORG"    	  => $conditions["NRORG"],
        		":CDFILIAL"		  => $conditions["CDFILIAL"],
        		":CDOPERADOR"     => $conditions["CDOPERADOR"]
        	);
        	
       return $this->entityManager->getConnection()->fetchAssoc(self::GET_IS_FILIAL_BLOQ, $params);
		
	}
	
	public function perfilUtlBloq ($conditions){
		$params = array(
        		":NRORG"    			      => $conditions["NRORG"],
        		":NRPERFILACESSO"		  => $conditions["CDPERFILSELECIONADO"]
        	);
        	
       return $this->entityManager->getConnection()->fetchAssoc(self::PERF_UTL_BLOQ, $params)['IDBLOCKFILIAL'] == 'N';
		
	}
	
	public function paramOperador ($conditions){
		$params = array(
        		":NRORG"    			      => $conditions["NRORG"],
        		":CDOPERADOR"		  => $conditions["CDOPERADOR"]
        	);
        	
       return $this->entityManager->getConnection()->fetchAssoc(self::GET_PARAM_OPERADOR, $params);
		
	}
	
	public function paramPerfilSelecionado($nrorg, $cdoperador){
		$params = array(
        		":NRORG"    			      => $nrorg,
        		":CDOPERADOR"		  => $cdoperador
        	);
        return $this->entityManager->getConnection()->fetchAssoc(self::GET_PERFIL_OPERADOR, $params);
	}
	
	/*DASHBOARD 2*/
	
	public function findV_QTTICKET($NRORG, $CDFILIAL, $DTVNDCARDS, $CDOPERADOR, $CHECK, $TCDFILIAL) {
		$result = null; 
		$QTNFEPEND = null;
		$QTNFEDIGIT = null;
		$QTNFSPEND = null;
		$QTNFSDIGIT = null;
		$QTNFEIMPORTXML = null;
		$QTNFEDIGITHAND = null;
		
		$params = array (
			':NRORG'	=> $NRORG,
			':CDFILIAL'	=> $CDFILIAL,
			':DTVNDCARDS'	=> $DTVNDCARDS,
			':TCDFILIAL'	=> $TCDFILIAL,
			':CDOPERADOR'	=> $CDOPERADOR
		);
		
		// IF QUE TRAZ TODAS UNIDADES DO OPERADOR LOGADO
		if($CHECK == 'S') {
			$result = $this->entityManager->getConnection()->fetchAll(self::GET_V_QTTICKET, $params);
		} else {
			$result = $this->entityManager->getConnection()->fetchAll(self::GET_V_QTTICKET_ALL, $params);
		}
		
		$QTNFEPEND = $this->entityManager->getConnection()->fetchAll(self::GET_NFE_PEND, $params)[0];
		$QTNFEDIGIT = $this->entityManager->getConnection()->fetchAll(self::GET_NFE_DIGIT, $params)[0];
		$QTNFSPEND = $this->entityManager->getConnection()->fetchAll(self::GET_NFS_PEND, $params)[0];
		$QTNFSDIGIT = $this->entityManager->getConnection()->fetchAll(self::GET_NFS_DIGIT, $params)[0];
		$QTNFSDIGITHAND = $this->entityManager->getConnection()->fetchAll(self::GET_NFS_DIGIT_HAND, $params)[0];
		$QTNFEIMPORTXML = $this->entityManager->getConnection()->fetchAll(self::GET_NFE_IMPORT_XML, $params)[0];
		$QTNFEDIGITHAND = $this->entityManager->getConnection()->fetchAll(self::GET_NFE_DIGIT_HAND, $params)[0];
		
		$result[0]["QTNFEPEND"] = (float)$QTNFEPEND['QTNFEPEND'];
		$result[0]["QTNFEDIGIT"] = (float)$QTNFEDIGIT['QTNFEDIGIT'];
		$result[0]["QTNFSPEND"] = (float)$QTNFSPEND['QTNFSPEND'];
		$result[0]["QTNFSDIGIT"] = (float)$QTNFSDIGIT['QTNFSDIGIT'];
		$result[0]["QTNFEIMPORTXML"] = (float)$QTNFEIMPORTXML['QTNFEIMPORTXML'];
		$result[0]["QTNFEDIGITHAND"] = (float)$QTNFEDIGITHAND['QTNFEDIGITHAND'];
		$result[0]["QTNFSDIGITHAND"] = (float)$QTNFSDIGITHAND['QTNFSDIGITHAND'];
		foreach ($result as &$values) {
        	$values['QTTICKETCARD'] 	= empty($values['QTTICKETCARD']) ? 0.00 : (float)$values['QTTICKETCARD'];
        	$values['TOTVENDCARD']		= empty($values['TOTVENDCARD']) ? 0.00 : (float)$values['TOTVENDCARD'];
        	$values['CANCVENDCARD'] 	= empty($values['CANCVENDCARD']) ? 0.00 : (float)$values['CANCVENDCARD'];
        	$values['FECHCAIXPENDCARD'] = empty($values['FECHCAIXPENDCARD']) ? 0.00 : (float)$values['FECHCAIXPENDCARD'];
        	$values['APROVMOVCARD'] 	= empty($values['APROVMOVCARD']) ? 0.00 : (float)$values['APROVMOVCARD'];
        	$values['DIFAPURACARD'] 	= empty($values['DIFAPURACARD']) ? 0.00 : (float)$values['DIFAPURACARD'];
        	$values['QTDIFAPURACARD']	= empty($values['QTDIFAPURACARD']) ? 0.00 : (float)$values['QTDIFAPURACARD'];
        	$values['CUPOMPENDCARD']	= empty($values['CUPOMPENDCARD']) ? 0.00 : (float)$values['CUPOMPENDCARD'];
        	$values['ITESTPENDCARD']	= empty($values['ITESTPENDCARD']) ? 0.00 : (float)$values['ITESTPENDCARD'];
        	$values['AVGTICKETCARD']	= empty($values['AVGTICKETCARD']) ? 0.00 : (float)$values['AVGTICKETCARD'];
        	$values['PRODIRREG']		= empty($values['PRODIRREG']) ? 0.00 : (float)$values['PRODIRREG'];
        }
		return $result;
	}
	
	//graphs
	
	public function findSaleGraph ($NRORG, $CDFILIAL, $DTVNDCARDS, $CDOPERADOR, $CHECK, $TCDFILIAL) {
		$result = null; 
		
		$params = array (
			':CDFILIAL'		=> $CDFILIAL,
			':TCDFILIAL'	=> $TCDFILIAL,
			':NRORG'		=> $NRORG,
			':CDOPERADOR'	=> $CDOPERADOR,
			':DTENTRVENDA'	=> $DTVNDCARDS
		);
        $return = $this->entityManager->getConnection()->fetchAll(self::GET_SALE_GRAPH, $params);
        $returnLY = $this->entityManager->getConnection()->fetchAll(self::GET_SALE_GRAPH_LAST_YEAR, $params);
        $arrayBase =  array(
						  array(
						    "QTVEND" => 0,
						    "TOTVENDA" => 0,
						    "TCKMEDIO" => 0,
						    "MES" => "JAN",
						    "ANO" => 0,
						    "QTVEND2" => 0,
						    "TOTVENDA2" => 0,
						    "TCKMEDIO2" => 0,
						    "MES2" => "JAN",
						    "VRMETA" => 0,
						    "ORDEM" => "01"
						  ),
						  array(
						    "QTVEND" => 0,
						    "TOTVENDA" => 0,
						    "TCKMEDIO" => 0,
						    "MES" => "FEV",
						    "ANO" => 0,
						    "QTVEND2" => 0,
						    "TOTVENDA2" => 0,
						    "TCKMEDIO2" => 0,
						    "MES2" => "FEV",
						    "VRMETA" => 0,
						    "ORDEM" => "02"
						  ),
						  array(
						    "QTVEND" => 0,
						    "TOTVENDA" => 0,
						    "TCKMEDIO" => 0,
						    "MES" => "MAR",
						    "ANO" => 0,
						    "QTVEND2" => 0,
						    "TOTVENDA2" => 0,
						    "TCKMEDIO2" => 0,
						    "MES2" => "MAR",
						    "VRMETA" => 0,
						    "ORDEM" => "03"
						  ),
						  array(
						    "QTVEND" => 0,
						    "TOTVENDA" => 0,
						    "TCKMEDIO" => 0,
						    "MES" => "ABR",
						    "ANO" => 0,
						    "QTVEND2" => 0,
						    "TOTVENDA2" => 0,
						    "TCKMEDIO2" => 0,
						    "MES2" => "ABR",
						    "VRMETA" => 0,
						    "ORDEM" => "04"
						  ),
						  array(
						    "QTVEND" => 0,
						    "TOTVENDA" => 0,
						    "TCKMEDIO" => 0,
						    "MES" => "MAI",
						    "ANO" => 0,
						    "QTVEND2" => 0,
						    "TOTVENDA2" => 0,
						    "TCKMEDIO2" => 0,
						    "MES2" => "MAI",
						    "VRMETA" => 0,
						    "ORDEM" => "05"
						  ),
						  array(
						    "QTVEND" => 0,
						    "TOTVENDA" => 0,
						    "TCKMEDIO" => 0,
						    "MES" => "JUN",
						    "ANO" => 0,
						    "QTVEND2" => 0,
						    "TOTVENDA2" => 0,
						    "TCKMEDIO2" => 0,
						    "MES2" => "JUN",
						    "VRMETA" => 0,
						    "ORDEM" => "06"
						  ),
					      array(
					        "QTVEND" => 0,
					        "TOTVENDA" => 0,
					        "TCKMEDIO" => 0,
					        "MES" => "JUL",
					        "ANO" => 0,
					        "QTVEND2" => 0,
					        "TOTVENDA2" => 0,
					        "TCKMEDIO2" => 0,
					        "MES2" => "JUL",
					        "VRMETA" => 0,
					        "ORDEM" => "07"
					      ),
					      array(
					        "QTVEND" => 0,
					        "TOTVENDA" => 0,
					        "TCKMEDIO" => 0,
					        "MES" => "AGO",
					        "ANO" => 0,
					        "QTVEND2" => 0,
					        "TOTVENDA2" => 0,
					        "TCKMEDIO2" => 0,
					        "MES2" => "AGO",
					        "VRMETA" => 0,
					        "ORDEM" => "08"
					      ),
					      array(
					        "QTVEND" => 0,
					        "TOTVENDA" => 0,
					        "TCKMEDIO" => 0,
					        "MES" => "SET",
					        "ANO" => 0,
					        "QTVEND2" => 0,
					        "TOTVENDA2" => 0,
					        "TCKMEDIO2" => 0,
					        "MES2" => "SET",
					        "VRMETA" => 0,
					        "ORDEM" => "09"
					      ),
					      array(
					        "QTVEND" => 0,
					        "TOTVENDA" => 0,
					        "TCKMEDIO" => 0,
					        "MES" => "OUT",
					        "ANO" => 0,
					        "QTVEND2" => 0,
					        "TOTVENDA2" => 0,
					        "TCKMEDIO2" => 0,
					        "MES2" => "OUT",
					        "VRMETA" => 0,
					        "ORDEM" => "10"
					      ),
					      array(
					        "QTVEND" => 0,
					        "TOTVENDA" => 0,
					        "TCKMEDIO" => 0,
					        "MES" => "NOV",
					        "ANO" => 0,
					        "QTVEND2" => 0,
					        "TOTVENDA2" => 0,
					        "TCKMEDIO2" => 0,
					        "MES2" => "NOV",
					        "VRMETA" => 0,
					        "ORDEM" => "11"
					      ),
					      array(
					        "QTVEND" => 0,
					        "TOTVENDA" => 0,
					        "TCKMEDIO" => 0,
					        "MES" => "DEZ",
					        "ANO" => 0,
					        "QTVEND2" => 0,
					        "TOTVENDA2" => 0,
					        "TCKMEDIO2" => 0,
					        "MES2" => "DEZ",
					        "VRMETA" => 0,
					        "ORDEM" => "12"
					      )
		);
        foreach ($arrayBase as $key => $values) {
			foreach ($return as $key2 => $values2) {
				if($arrayBase[$key]['ORDEM'] == $values2['ORDEM']){
		        	$arrayBase[$key]['ORDEM'] = (float)$values2['ORDEM'];
		        	$arrayBase[$key]['QTVEND'] = (float)$values2['QTVEND'];
		        	$arrayBase[$key]['TCKMEDIO'] = (float)$values2['TCKMEDIO'];
		        	$arrayBase[$key]['TOTVENDA'] = (float)$values2['TOTVENDA'];
		        	$arrayBase[$key]['VRMETA'] = (float)$values2['VRMETA'];
				}
			}
			foreach ($returnLY as $keyLY => $valuesLY) {
				if($arrayBase[$key]['ORDEM'] == $valuesLY['ORDEM']){
		        	$arrayBase[$key]['ORDEM'] = (float)$valuesLY['ORDEM'];
		        	$arrayBase[$key]['QTVEND2'] = (float)$valuesLY['QTVEND2'];
		        	$arrayBase[$key]['TCKMEDIO2'] = (float)$valuesLY['TCKMEDIO2'];
		        	$arrayBase[$key]['TOTVENDA2'] = (float)$valuesLY['TOTVENDA2'];
		        	$arrayBase[$key]['VRMETA'] = (float)$valuesLY['VRMETA'];
				}
			}
        }
        return $arrayBase;
	}
	
	public function findSaleTypeGraph ($NRORG, $CDFILIAL, $DTVNDCARDS, $CDOPERADOR, $CHECK, $TCDFILIAL) {
		$result = null; 
		
		$params = array (
			':CDFILIAL'		=> $CDFILIAL,
			':TCDFILIAL'	=> $TCDFILIAL,
			':NRORG'		=> $NRORG,
			':CDOPERADOR'	=> $CDOPERADOR,
			':DTENTRVENDA'	=> $DTVNDCARDS
		);
		
        $return = $this->entityManager->getConnection()->fetchAll(self::GET_SALE_TYPE_GRAPH, $params);
        foreach ($return as &$values) {
        	$values['TOTAL'] = (float)$values['TOTAL'];
        	$values['TOTVENDA'] = (float)$values['TOTVENDA'];
        	$values['PERCENT'] = (float)$values['PERCENT'];
        }
        return $return;
	}
	
	public function findSalePaymentGraph ($NRORG, $CDFILIAL, $DTVNDCARDS, $CDOPERADOR, $CHECK, $TCDFILIAL) {
		$result = null; 
		
		$params = array (
			':CDFILIAL'		=> $CDFILIAL,
			':TCDFILIAL'	=> $TCDFILIAL,
			':NRORG'		=> $NRORG,
			':CDOPERADOR'	=> $CDOPERADOR,
			':DTENTRVENDA'	=> $DTVNDCARDS
		);
        $return = $this->entityManager->getConnection()->fetchAll(self::GET_SALE_PAYMENT_FOR_DAY, $params);
        foreach ($return as &$values) {
        	$values['TOT'] = (float)$values['TOT'];
        }
        return $return;
	}
	
	public function findSaleForDayGraph ($NRORG, $CDFILIAL, $DTVNDCARDS, $CDOPERADOR, $CHECK, $TCDFILIAL) {
		$result = null; 
		
		$params = array (
			':CDFILIAL'		=> $CDFILIAL,
			':TCDFILIAL'	=> $TCDFILIAL,
			':NRORG'		=> $NRORG,
			':CDOPERADOR'	=> $CDOPERADOR,
			':DTENTRVENDA'	=> $DTVNDCARDS
		);
		
        $return = $this->entityManager->getConnection()->fetchAll(self::GET_SALE_FOR_DAY, $params);;
        foreach ($return as &$values) {
        	$values['TOTVENDA'] = (float)$values['TOTVENDA'];
        	$values['PERC'] = (float)$values['PERC'];
        }
        return $return;
	}
	
	//Tabelas 
	
	public function findProdutoMaiorCusto ($NRORG, $CDFILIAL, $DTVNDCARDS, $CDOPERADOR, $CHECK, $TCDFILIAL) {
		$result = null; 
		
		$params = array (
			':CDFILIAL'		=> $CDFILIAL,
			':TCDFILIAL'	=> $TCDFILIAL,
			':NRORG'		=> $NRORG,
			':CDOPERADOR'	=> $CDOPERADOR,
			':DTENTRVENDA'	=> $DTVNDCARDS
		);
        return $this->entityManager->getConnection()->fetchAll(self::TAB_RNK_MAIOR_CUSTO, $params);
	}
	
	public function findProdutoMenorCusto ($NRORG, $CDFILIAL, $DTVNDCARDS, $CDOPERADOR, $CHECK, $TCDFILIAL) {
		$result = null; 
		
		$params = array (
			':CDFILIAL'		=> $CDFILIAL,
			':TCDFILIAL'	=> $TCDFILIAL,
			':NRORG'		=> $NRORG,
			':CDOPERADOR'	=> $CDOPERADOR,
			':DTENTRVENDA'	=> $DTVNDCARDS
		);
        return $this->entityManager->getConnection()->fetchAll(self::TAB_RNK_MENOR_CUSTO, $params);
	}
	
	public function findProdMaisAjustes ($NRORG, $CDFILIAL, $DTVNDCARDS, $CDOPERADOR, $CHECK, $TCDFILIAL) {
		$result = null; 
		
		$params = array (
			':CDFILIAL'		=> $CDFILIAL,
			':TCDFILIAL'	=> $TCDFILIAL,
			':NRORG'		=> $NRORG,
			':CDOPERADOR'	=> $CDOPERADOR,
			':DTENTRVENDA'	=> $DTVNDCARDS
		);
        return $this->entityManager->getConnection()->fetchAll(self::TAB_PROD_MAIS_AJUSTES, $params);
	}
	
	public function findUnidadeSemContagem ($NRORG, $CDFILIAL, $DTVNDCARDS, $CDOPERADOR, $CHECK, $TCDFILIAL) {
		$result = null; 
		
		$params = array (
			':CDFILIAL'		=> $CDFILIAL,
			':TCDFILIAL'	=> $TCDFILIAL,
			':NRORG'		=> $NRORG,
			':CDOPERADOR'	=> $CDOPERADOR,
			':DTENTRVENDA'	=> $DTVNDCARDS
		);
        return $this->entityManager->getConnection()->fetchAll(self::TAB_UNIDADES_SEM_CONTAGEM, $params);
	}
	
	public function findUltimaContagem ($NRORG, $CDFILIAL, $DTVNDCARDS, $CDOPERADOR, $CHECK, $TCDFILIAL) {
		$result = null; 
		
		$params = array (
			':CDFILIAL'		=> $CDFILIAL,
			':TCDFILIAL'	=> $TCDFILIAL,
			':NRORG'		=> $NRORG,
			':CDOPERADOR'	=> $CDOPERADOR,
			':DTENTRVENDA'	=> $DTVNDCARDS
		);
        return $this->entityManager->getConnection()->fetchAll(self::TAB_ULTIMO_AJUSTE, $params);
	}
	
	public function findContasPagar ($NRORG, $CDFILIAL, $DTVNDCARDS, $CDOPERADOR, $CHECK, $TCDFILIAL) {
		$result = null; 
		$array = [];
		$params = array (
			':CDFILIAL'		=> $CDFILIAL,
			':TCDFILIAL'	=> $TCDFILIAL,
			':NRORG'		=> $NRORG,
			':CDOPERADOR'	=> $CDOPERADOR,
			':DTENTRVENDA'	=> $DTVNDCARDS
		);
        $result = $this->entityManager->getConnection()->fetchAll(self::TAB_CONTAS_PAGAR, $params);
        foreach ($result as $value) {
        	$array = array(
				[
					'LABELVALIDADE' => 'Pagar Hoje',
					'VALOR' => $value['VRVENCDIA']
				],
				[
					'LABELVALIDADE' => 'Vencidos',
					'VALOR' => $value['VRTOTALVENCIDO']
				],
				[
					'LABELVALIDADE' => 'Vencimento em 7 Dias',
					'VALOR' => $value['VRVENC7DIAS']
				],
				[
					'LABELVALIDADE' => 'Vencimento em 15 Dias',
					'VALOR' => $value['VRVENC15DIAS']
				],
				[
					'LABELVALIDADE' => 'Vencimento em 30 Dias',
					'VALOR' => $value['VRVENC30DIAS']
				]
			);
        }
        return $array;
	}
	
	public function findContasReceber ($NRORG, $CDFILIAL, $DTVNDCARDS, $CDOPERADOR, $CHECK, $TCDFILIAL) {
		$result = null; 
		$array = [];
		$params = array (
			':CDFILIAL'		=> $CDFILIAL,
			':TCDFILIAL'	=> $TCDFILIAL,
			':NRORG'		=> $NRORG,
			':CDOPERADOR'	=> $CDOPERADOR,
			':DTENTRVENDA'	=> $DTVNDCARDS
		);
        $result = $this->entityManager->getConnection()->fetchAll(self::TAB_CONTAS_RECEBER, $params);
        foreach ($result as $value) {
        	$array = array(
				[
					'LABELVALIDADE' => 'Pagar Hoje',
					'VALOR' => $value['VRVENCDIA']
				],
				[
					'LABELVALIDADE' => 'Vencidos',
					'VALOR' => $value['VRTOTALVENCIDO']
				],
				[
					'LABELVALIDADE' => 'Vencimento em 7 Dias',
					'VALOR' => $value['VRVENC7DIAS']
				],
				[
					'LABELVALIDADE' => 'Vencimento em 15 Dias',
					'VALOR' => $value['VRVENC15DIAS']
				],
				[
					'LABELVALIDADE' => 'Vencimento em 30 Dias',
					'VALOR' => $value['VRVENC30DIAS']
				]
			);
        }
        return $array;
	}
	
	public function findSaldoEmContas ($NRORG, $CDFILIAL, $DTVNDCARDS, $CDOPERADOR, $CHECK, $TCDFILIAL) {
		$result = null; 
		
		$params = array (
			':CDFILIAL'		=> $CDFILIAL,
			':TCDFILIAL'	=> $TCDFILIAL,
			':NRORG'		=> $NRORG,
			':CDOPERADOR'	=> $CDOPERADOR,
			':DTENTRVENDA'	=> $DTVNDCARDS
		);
        return $this->entityManager->getConnection()->fetchAll(self::TAB_SALDO_EM_CONTA, $params);
	}
	
	public function findStatusNotaTab ($NRORG, $CDFILIAL, $DTVNDCARDS, $CDOPERADOR, $CHECK, $TCDFILIAL) {
		$result = null; 
		
		$params = array (
			':CDFILIAL'		=> $CDFILIAL,
			':TCDFILIAL'	=> $TCDFILIAL,
			':NRORG'		=> $NRORG,
			':CDOPERADOR'	=> $CDOPERADOR,
			':DTENTRVENDA'	=> $DTVNDCARDS
		);
        return $this->entityManager->getConnection()->fetchAll(self::TAB_STATUS_NOTA, $params);
	}
	
	public function findCMVTab ($NRORG, $CDFILIAL, $DTVNDCARDS, $CDOPERADOR, $CHECK, $TCDFILIAL) {
		$result = null; 
		
		$params = array (
			':CDFILIAL'		=> $CDFILIAL,
			':TCDFILIAL'	=> $TCDFILIAL,
			':NRORG'		=> $NRORG,
			':CDOPERADOR'	=> $CDOPERADOR,
			':DTENTRVENDA'	=> $DTVNDCARDS
		);
        return $this->entityManager->getConnection()->fetchAll(self::TAB_CMV, $params);
	}
	
	const GET_IS_FILIAL_BLOQ = "
		SELECT FILIAL.NMFILIAL, FILIAL.NRORG, FILIAL.IDSTATUSBLOQ
		  FROM FILIAL
		 INNER JOIN FILIOPER FI
			ON FILIAL.CDFILIAL    = FI.CDFILIAL
		   AND CDOPERADOR        = :CDOPERADOR
		   AND FILIAL.NRORG      = FI.NRORG
		 WHERE FILIAL.NRORG    = :NRORG
		   AND FILIAL.IDCNTRRESC = 'N'
		   AND FILIAL.CDFILIAL = :CDFILIAL
		   AND FILIAL.IDSTATUSBLOQ = 'S'
		 ORDER BY FILIAL.CDFILIAL
	";
	
	const PERF_UTL_BLOQ = "
		SELECT IDBLOCKFILIAL 
		  FROM PERFILACESSO 
		 WHERE NRPERFILACESSO = :NRPERFILACESSO
		   AND NRORG = :NRORG
	";
	
	const GET_PARAM_OPERADOR = "
		SELECT O.CDPERFILSELECIONADO AS CDPERFILACESSO, PF.NMPERFILACESSO, O.CDOPERADOR
		  FROM OPERADOR O
	      JOIN PERFILACESSO PF 
	    	ON PF.NRPERFILACESSO = O.CDPERFILSELECIONADO
	     WHERE O.CDOPERADOR = :CDOPERADOR 
	       AND O.NRORG 	 = :NRORG
	";
	    
	const GET_PERFIL_OPERADOR = "
		SELECT CDPERFILSELECIONADO 
		  FROM OPERADOR 
		 WHERE CDOPERADOR = :CDOPERADOR 
		   AND NRORG = :NRORG
	";
	
	/*DASHBOARD 2*/
	
	const GET_V_QTTICKET = "
		SELECT SUM(NVL(V.QTTICKETCARD, 0 )) QTTICKETCARD, SUM( NVL(V.TOTVENDCARD, 0 ) ) TOTVENDCARD,
			   SUM( NVL(V.CANCVENDCARD, 0 ) ) CANCVENDCARD, SUM( NVL(V.FECHCAIXPENDCARD, 0 ) ) FECHCAIXPENDCARD,
				SUM( NVL(V.APROVMOVCARD, 0 ) ) APROVMOVCARD, SUM( NVL(V.DIFAPURACARD, 0 ) ) DIFAPURACARD,
				SUM( NVL(V.QTDIFAPURACARD, 0 ) ) QTDIFAPURACARD, SUM( NVL(V.CUPOMPENDCARD, 0 ) ) CUPOMPENDCARD,
				SUM( NVL(V.ITESTPENDCARD, 0 ) ) ITESTPENDCARD, SUM( NVL(V.AVGTICKETCARD, 0)  )AVGTICKETCARD,
				SUM( NVL(V.PRODIRREG, 0)  ) PRODIRREG
		  FROM VNDCARDS V
		  JOIN FILIOPER F
		    ON V.CDFILIAL = F.CDFILIAL
		   AND V.NRORG = F.NRORG
		 WHERE ((INSTR(:CDFILIAL , V.CDFILIAL ) <> 0) OR (:TCDFILIAL = 'T'))
		   AND V.NRORG = :NRORG 
		   AND V.DTVNDCARDS = :DTVNDCARDS 
           AND F.CDOPERADOR = :CDOPERADOR
	";
	
	const GET_V_QTTICKET_ALL = "
		SELECT SUM(NVL(V.QTTICKETCARD, 0 )) QTTICKETCARD, SUM( NVL(V.TOTVENDCARD, 0 ) ) TOTVENDCARD,
			   SUM( NVL(V.CANCVENDCARD, 0 ) ) CANCVENDCARD, SUM( NVL(V.FECHCAIXPENDCARD, 0 ) ) FECHCAIXPENDCARD,
				SUM( NVL(V.APROVMOVCARD, 0 ) ) APROVMOVCARD, SUM( NVL(V.DIFAPURACARD, 0 ) ) DIFAPURACARD,
				SUM( NVL(V.QTDIFAPURACARD, 0 ) ) QTDIFAPURACARD, SUM( NVL(V.CUPOMPENDCARD, 0 ) ) CUPOMPENDCARD,
				SUM( NVL(V.ITESTPENDCARD, 0 ) ) ITESTPENDCARD, SUM( NVL(V.AVGTICKETCARD, 0)  )AVGTICKETCARD,
				SUM( NVL(V.PRODIRREG, 0)  ) PRODIRREG
		  FROM VNDCARDS V
		  JOIN FILIOPER F
		    ON V.CDFILIAL = F.CDFILIAL
		   AND V.NRORG = F.NRORG
		 WHERE V.NRORG = :NRORG 
		   AND V.DTVNDCARDS = :DTVNDCARDS 
           AND F.CDOPERADOR = :CDOPERADOR
	";
	
	//PEND -> PENDENTE
	//DIGIT -> EM DIGITAÇÃO
	//HAND -> MANUALMENTE
	
	// Notas fiscais de entrada Pendentes
	
	const GET_NFE_PEND = "
		SELECT COUNT(*) QTNFEPEND
		  FROM NOTAFISCAL N
		  JOIN FILIOPER F
		    ON N.CDFILIAL = F.CDFILIAL
		   AND N.NRORG = F.NRORG
	     WHERE F.CDOPERADOR = :CDOPERADOR
	       AND N.NRORG = :NRORG
	       AND N.IDSTATUS = 'P'
	       AND N.IDSISTEMA = 'DFE'
	       AND N.IDENTRSAIDOP = 'E'
	       AND ((INSTR(:CDFILIAL , N.CDFILIRECE ) <> 0) OR (:TCDFILIAL = 'T'))
	       AND TRUNC(N.DTENTRSAID) = :DTVNDCARDS
	";
	
	// Notas fiscais de entrada em digitação
	
	const GET_NFE_DIGIT = "
		SELECT COUNT(*) QTNFEDIGIT
		  FROM NOTAFISCAL N
		  JOIN FILIOPER F
		    ON N.CDFILIAL = F.CDFILIAL
		   AND N.NRORG = F.NRORG
	     WHERE F.CDOPERADOR = :CDOPERADOR
	       AND N.NRORG = :NRORG
	       AND N.IDSTATUS = 'D'
		   AND N.IDSISTEMA = 'DFE'
		   AND N.IDENTRSAIDOP = 'E'
		   AND ((INSTR(:CDFILIAL , N.CDFILIRECE ) <> 0) OR (:TCDFILIAL = 'T'))
		   AND TRUNC(N.DTENTRSAID) = :DTVNDCARDS
	";
	
	// Notas fiscais de saida Pendentes
	
	const GET_NFS_PEND = "
		SELECT COUNT(*) QTNFSPEND
		  FROM NOTAFISCAL N
		  JOIN FILIOPER F
		    ON N.CDFILIAL = F.CDFILIAL
		   AND N.NRORG = F.NRORG
	     WHERE F.CDOPERADOR = :CDOPERADOR
	       AND N.NRORG = :NRORG
	       AND N.IDSTATUS = 'P'
		   AND N.IDSISTEMA = 'DFS'
		   AND N.IDENTRSAIDOP = 'S'
		   AND ((INSTR(:CDFILIAL , N.CDFILIEMIT ) <> 0) OR (:TCDFILIAL = 'T'))
		   AND TRUNC(N.DTENTRSAID) = :DTVNDCARDS
	";
	
	// Notas fiscais de saida em digitação
	
	const GET_NFS_DIGIT = "
		SELECT COUNT(*) QTNFSDIGIT
		  FROM NOTAFISCAL N
		  JOIN FILIOPER F
		    ON N.CDFILIAL = F.CDFILIAL
		   AND N.NRORG = F.NRORG
	     WHERE F.CDOPERADOR = :CDOPERADOR
	       AND N.NRORG = :NRORG
	       AND N.IDSTATUS = 'D'
		   AND N.IDSISTEMA = 'DFS'
		   AND N.IDENTRSAIDOP = 'S'
		   AND ((INSTR(:CDFILIAL , N.CDFILIEMIT ) <> 0) OR (:TCDFILIAL = 'T'))
		   AND TRUNC(N.DTENTRSAID) = :DTVNDCARDS
	";
	
	// Notas fiscais importadas via XML
	
	const GET_NFE_IMPORT_XML = "
		SELECT COUNT(*) QTNFEIMPORTXML
		  FROM NOTAFISCAL N
		  JOIN FILIOPER F
		    ON N.CDFILIAL = F.CDFILIAL
		   AND N.NRORG = F.NRORG
	     WHERE F.CDOPERADOR = :CDOPERADOR
	       AND N.NRORG = :NRORG
	       AND N.IDNFGERADAVIAXML = 'S'
		   AND N.IDSISTEMA = 'DFE'
		   AND N.IDENTRSAIDOP = 'E'
		   AND ((INSTR(:CDFILIAL , N.CDFILIRECE ) <> 0) OR (:TCDFILIAL = 'T'))
		   AND TRUNC(N.DTENTRSAID) = :DTVNDCARDS
	";
	
	// Notas fiscais digitadas manualmente
	
	const GET_NFE_DIGIT_HAND = "
		SELECT COUNT(*) QTNFEDIGITHAND
		  FROM NOTAFISCAL N
		  JOIN FILIOPER F
		    ON N.CDFILIAL = F.CDFILIAL
		   AND N.NRORG = F.NRORG
	     WHERE F.CDOPERADOR = :CDOPERADOR
	       AND N.NRORG = :NRORG
	       AND N.IDNFGERADAVIAXML = 'N'
		   AND N.IDSISTEMA = 'DFE'
		   AND N.IDENTRSAIDOP = 'E'
		   AND ((INSTR(:CDFILIAL , N.CDFILIRECE ) <> 0) OR (:TCDFILIAL = 'T'))
		   AND TRUNC(N.DTENTRSAID) = :DTVNDCARDS
	";
	
	// Notas fiscais digitadas manualmente
	
	const GET_NFS_DIGIT_HAND = "
		SELECT COUNT(*) QTNFSDIGITHAND
		  FROM NOTAFISCAL N
		  JOIN FILIOPER F
		    ON N.CDFILIAL = F.CDFILIAL
		   AND N.NRORG = F.NRORG
	     WHERE F.CDOPERADOR = :CDOPERADOR
	       AND N.NRORG = :NRORG
	       AND N.IDSISTEMA = 'DFS'
		   AND N.IDENTRSAIDOP = 'S'
		   AND ((INSTR(:CDFILIAL , N.CDFILIEMIT ) <> 0) OR (:TCDFILIAL = 'T'))
		   AND TRUNC(N.DTENTRSAID) = :DTVNDCARDS
	";
	
	// Graphics but not Graphql
	
	const GET_SALE_GRAPH = "
		SELECT TO_NUMBER(COUNT(V.NRSEQVENDA)) AS QTVEND, TO_NUMBER(SUM(NVL(V.VRTOTVENDA,0))) AS TOTVENDA, TO_NUMBER(TRUNC(SUM (NVL(V.VRTOTVENDA,0))/ COUNT(V.NRSEQVENDA),2)) AS TCKMEDIO, 
			   TO_CHAR(V.DTENTRVENDA, 'MON') AS MES, TO_CHAR(V.DTENTRVENDA, 'YYYY') AS ANO, TO_NUMBER(NVL(M.VRMES,0)) AS VRMETA, TO_CHAR(V.DTENTRVENDA, 'MM') AS ORDEM
		  FROM VENDA V
		  JOIN (SELECT FO.CDFILIAL, FO.CDOPERADOR, FO.NRORG
		          FROM FILIOPER FO
		          JOIN (SELECT CDFILIAL, NRORG
		                  FROM FILIAL
		                 WHERE ((INSTR(:CDFILIAL , CDFILIAL ) <> 0) OR (:TCDFILIAL = 'T'))
		                   AND NRORG = :NRORG
		               ) F
		            ON FO.CDFILIAL = F.CDFILIAL
		           AND FO.NRORG = F.NRORG
		         WHERE FO.CDOPERADOR = :CDOPERADOR
		       ) F
		    ON V.CDFILIAL = F.CDFILIAL
		   AND V.NRORG = F.NRORG
        	   LEFT JOIN( SELECT SUM(M.VRMES) AS VRMES, M.CDANO, TO_CHAR(TO_DATE(M.CDMES, 'MM'), 'MON') AS CDMES
                    	    FROM METAMES M
                            JOIN (SELECT FO.CDFILIAL, FO.CDOPERADOR, FO.NRORG
                                    FROM FILIOPER FO
                                    JOIN (SELECT CDFILIAL, NRORG
                                		    FROM FILIAL
                                    	   WHERE ((INSTR(:CDFILIAL , CDFILIAL ) <> 0) OR (:TCDFILIAL = 'T'))
                                    		 AND NRORG = :NRORG
                                		 ) F
                                	  ON FO.CDFILIAL = F.CDFILIAL
	                                 AND FO.NRORG = F.NRORG
                            	   WHERE FO.CDOPERADOR = :CDOPERADOR
	                             ) F
                    		  ON M.CDFILIAL = F.CDFILIAL
                           WHERE M.CDANO = TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'YYYY')
	                       GROUP BY M.CDANO, M.CDMES
                 		) M
        			 ON TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'YYYY') = M.CDANO
        			AND  TO_CHAR(V.DTENTRVENDA, 'MON') = M.CDMES
			      WHERE V.IDSITUVENDA = 'O' 
					AND NVL(V.IDSTATUSNFCE,'T') <> 'R'
                    AND TO_CHAR(V.DTENTRVENDA, 'YYYY') = TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'YYYY')
				  GROUP BY TO_CHAR(V.DTENTRVENDA, 'MON'), TO_CHAR(V.DTENTRVENDA, 'YYYY'), M.VRMES, TO_CHAR(V.DTENTRVENDA, 'MM')
				  ORDER BY TO_CHAR(V.DTENTRVENDA, 'MM'), TO_CHAR(V.DTENTRVENDA, 'YYYY')
	";
	
	const GET_SALE_GRAPH_LAST_YEAR = "
		SELECT NVL(COUNT(V.NRSEQVENDA),0) AS QTVEND2, NVL(SUM(NVL(V.VRTOTVENDA,0)),0) AS TOTVENDA2, TRUNC(SUM (NVL(V.VRTOTVENDA,0))/ COUNT(V.NRSEQVENDA),2) AS TCKMEDIO2, TO_CHAR(V.DTENTRVENDA, 'MON') AS MES2, 
        		TO_CHAR(V.DTENTRVENDA, 'YYYY') AS ANO2, TO_NUMBER(NVL(M.VRMES,0)) AS VRMETA, TO_CHAR(V.DTENTRVENDA, 'MM') AS ORDEM
    	   FROM VENDA V
    	   JOIN (SELECT FO.CDFILIAL, FO.CDOPERADOR, FO.NRORG
            	   FROM FILIOPER FO
            	   JOIN (SELECT CDFILIAL, NRORG
                		   FROM FILIAL
                    	  WHERE ((INSTR(:CDFILIAL , CDFILIAL ) <> 0) OR (:TCDFILIAL = 'T'))
                    		AND NRORG = :NRORG
                		) F
            		 ON FO.CDFILIAL = F.CDFILIAL
            		AND FO.NRORG = F.NRORG
            	  WHERE FO.CDOPERADOR = :CDOPERADOR
        		) F
    		 ON V.CDFILIAL = F.CDFILIAL
    		AND V.NRORG = F.NRORG
    	   LEFT JOIN( SELECT SUM(M.VRMES) AS VRMES, M.CDANO, TO_CHAR(TO_DATE(M.CDMES, 'MM'), 'MON') AS CDMES
                	    FROM METAMES M
                        JOIN (SELECT FO.CDFILIAL, FO.CDOPERADOR, FO.NRORG
                                FROM FILIOPER FO
                                JOIN (SELECT CDFILIAL, NRORG
                            		    FROM FILIAL
                                	   WHERE ((INSTR(:CDFILIAL , CDFILIAL ) <> 0) OR (:TCDFILIAL = 'T'))
                                		 AND NRORG = :NRORG
                            		 ) F
                            	  ON FO.CDFILIAL = F.CDFILIAL
                                 AND FO.NRORG = F.NRORG
                        	   WHERE FO.CDOPERADOR = :CDOPERADOR
                             ) F
                		  ON M.CDFILIAL = F.CDFILIAL
                       WHERE M.CDANO = TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'YYYY')
                       GROUP BY M.CDANO, M.CDMES
             		) M
    			 ON TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'YYYY') = M.CDANO
    			AND  TO_CHAR(V.DTENTRVENDA, 'MON') = M.CDMES
    	  WHERE V.IDSITUVENDA = 'O' 
    		AND NVL(V.IDSTATUSNFCE,'T') <> 'R'
    		AND TO_CHAR(V.DTENTRVENDA, 'YYYY') = TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'YYYY')-1
    	  GROUP BY TO_CHAR(V.DTENTRVENDA, 'MON'), TO_CHAR(V.DTENTRVENDA, 'YYYY'), M.VRMES, TO_CHAR(V.DTENTRVENDA, 'MM')
		  ORDER BY TO_CHAR(V.DTENTRVENDA, 'MM'), TO_CHAR(V.DTENTRVENDA, 'YYYY')
	";
	
	const GET_SALE_TYPE_GRAPH = "
		SELECT TOTAL, MODALIDADE, SUM (TOTVENDA) AS TOTVENDA, SUM(PERCENT) AS PERCENT
		  FROM (SELECT (SUM(TOTVENDA) OVER ( PARTITION BY BASE )) AS TOTAL, MODALIDADE, TOTVENDA, ROUND(((TOTVENDA/(SUM(TOTVENDA) OVER (PARTITION BY BASE)))* 100), 2) AS PERCENT 
		        FROM ( SELECT SUM (NVL(V.VRTOTVENDA,0)) AS TOTVENDA, CASE SUBSTR(V.IDORIGEMVENDA, 0, 3)
		                      WHEN 'DLV' THEN 'DELIVERY'
		                      WHEN 'MES' THEN 'MESA'
		                      WHEN 'BAL' THEN (CASE SUBSTR(V.IDORIGEMVENDA, 5, 7) WHEN 'AUT' THEN 'TERMINAL DE AUTO-ATENDIMENTO' ELSE 'BALCAO' END) 
		                      WHEN 'TAA' THEN 'TERMINAL DE AUTO-ATENDIMENTO'
		                      WHEN 'CMD' THEN 'COMANDA'
		                      WHEN 'AJU' THEN 'OUTROS' ELSE 'OUTROS'
		                      END AS MODALIDADE, 1 AS BASE
		                 FROM VENDA V
		                 JOIN ( SELECT FO.CDFILIAL, FO.CDOPERADOR, FO.NRORG
		                          FROM FILIOPER FO
		                          JOIN (SELECT CDFILIAL, NRORG
		                                  FROM FILIAL
		                                 WHERE ((INSTR(:CDFILIAL , CDFILIAL ) <> 0) OR (:TCDFILIAL = 'T'))
		                                   AND NRORG = :NRORG
		                               ) F
		                            ON FO.CDFILIAL = F.CDFILIAL
		                           AND FO.NRORG = F.NRORG
		                         WHERE FO.CDOPERADOR = :CDOPERADOR
		                      ) F
		                   ON V.CDFILIAL = F.CDFILIAL
		                  AND V.NRORG = F.NRORG
		                WHERE V.IDSITUVENDA = 'O' 
		                  AND NVL(V.IDSTATUSNFCE,'T') <> 'R'
		                  AND TO_CHAR(V.DTENTRVENDA, 'YYYY') = TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'YYYY')
		                GROUP BY SUBSTR(V.IDORIGEMVENDA, 0, 3), SUBSTR(V.IDORIGEMVENDA, 5, 7)
		                ORDER BY SUBSTR(V.IDORIGEMVENDA, 0, 3)
		              )) 
		GROUP BY TOTAL, MODALIDADE
	";
	
	const GET_SALE_PAYMENT_FOR_DAY = "
	  SELECT SUM(VR) AS TOT, CDTIPORECE, NMTIPORECE
		FROM (SELECT SUM(M.VRMOVIVEND) VR, M.CDTIPORECE, T.NMTIPORECE
			    FROM MOVCAIXA M
			    JOIN TIPORECE T
			      ON M.CDTIPORECE = T.CDTIPORECE
			     AND M.NRORG = T.NRORG
			    JOIN (SELECT FO.CDFILIAL, FO.CDOPERADOR, FO.NRORG
			            FROM FILIOPER FO
			            JOIN (SELECT CDFILIAL, NRORG
			                    FROM FILIAL
			                   WHERE ((INSTR(:CDFILIAL , CDFILIAL ) <> 0) OR (:TCDFILIAL = 'T'))
			                     AND NRORG = :NRORG
			                 ) F
			              ON FO.CDFILIAL = F.CDFILIAL
			             AND FO.NRORG = F.NRORG
			           WHERE FO.CDOPERADOR = :CDOPERADOR
			         ) F
			      ON M.CDFILIAL = F.CDFILIAL
			     AND M.NRORG = F.NRORG 
			   WHERE M.IDTIPOMOVIVE = 'E'
			     AND M.NRSEQVENDA IS NOT NULL
			     AND M.DTMOVIMCAIXA = :DTENTRVENDA
			   GROUP BY M.CDTIPORECE, T.NMTIPORECE
		   
		       UNION ALL
		   
			  SELECT (SUM(M.VRMOVIVEND))*-1 VR,  M.CDTIPORECE, T.NMTIPORECE
				FROM MOVCAIXA M
				JOIN TIPORECE T
			      ON M.CDTIPORECE = T.CDTIPORECE
			     AND M.NRORG = T.NRORG
			    JOIN (SELECT FO.CDFILIAL, FO.CDOPERADOR, FO.NRORG
			            FROM FILIOPER FO
			            JOIN (SELECT CDFILIAL, NRORG
			                    FROM FILIAL
			                   WHERE ((INSTR(:CDFILIAL , CDFILIAL ) <> 0) OR (:TCDFILIAL = 'T'))
			                     AND NRORG = :NRORG
			                 ) F
			              ON FO.CDFILIAL = F.CDFILIAL
			             AND FO.NRORG = F.NRORG
			           WHERE FO.CDOPERADOR = :CDOPERADOR
			         ) F
			      ON M.CDFILIAL = F.CDFILIAL
			     AND M.NRORG = F.NRORG 
			   WHERE M.IDTIPOMOVIVE = 'S'
			     AND M.NRSEQVENDA IS NOT NULL
			     AND M.DTMOVIMCAIXA = :DTENTRVENDA
			   GROUP BY M.CDTIPORECE, T.NMTIPORECE)
		 GROUP BY CDTIPORECE, NMTIPORECE
		 ORDER BY 1 DESC
	";
	
	const GET_SALE_FOR_DAY = "
		SELECT A.CDFILIAL||' - '||A.NMFILIAL AS LABELFILIAL, A.NRORG, A.DTENTRVENDA, A.TOTVENDA, ROUND(( (A.TOTVENDA /(SUM(A.TOTVENDA) OVER (PARTITION BY A.NRORG)))*100), 2)||'%' AS PERC
		 FROM (SELECT F.CDFILIAL, F.NMFILIAL, F.NRORG, V.DTENTRVENDA, SUM(V.VRTOTVENDA) AS TOTVENDA
			     FROM VENDA V
			     JOIN (SELECT FO.CDFILIAL, FO.CDOPERADOR, FO.NRORG, F.NMFILIAL
					     FROM FILIOPER FO
					     JOIN (SELECT CDFILIAL, NRORG, NMFILIAL
					             FROM FILIAL
					            WHERE ((INSTR(:CDFILIAL , CDFILIAL ) <> 0) OR (:TCDFILIAL = 'T'))
					              AND NRORG = :NRORG
					          ) F
					       ON FO.CDFILIAL = F.CDFILIAL
					      AND FO.NRORG = F.NRORG
					    WHERE FO.CDOPERADOR = :CDOPERADOR
					  ) F
			       ON V.CDFILIAL = F.CDFILIAL
			      AND V.NRORG = F.NRORG
			    WHERE V.DTENTRVENDA = :DTENTRVENDA
			    GROUP BY F.CDFILIAL, F.NMFILIAL, F.NRORG, V.DTENTRVENDA) A
		ORDER BY 1
	";
	
	// Tabelas Dashboard 
	
	const TAB_RNK_MENOR_CUSTO = "
		SELECT B.CDARVPROD, B.NMPRODUTO, ROUND(B.VRCUSTO,10) AS VRCUSTO
		  FROM (SELECT A.CDARVPROD, A.NMPRODUTO, AVG(VRCUSTO) AS VRCUSTO
		          FROM (SELECT B.CDFILIAL, P.CDARVPROD, P.NMPRODUTO,
		                       NVL(CUSTO_PRODUTO(B.CDFILIAL, B.CDPRODUTO, (SELECT NVL(TO_NUMBER(CDTIPCUSTEST),3)
		                                                                              FROM PARAMFILIAL
		                                                                             WHERE CDFILIAL = B.CDFILIAL), :DTENTRVENDA, SYSDATE),0) AS VRCUSTO
		
		                  FROM POSESTCONS B
		                       JOIN PRODUTO P
		                          ON P.CDPRODUTO = B.CDPRODUTO
		                       JOIN (SELECT FO.CDFILIAL, FO.CDOPERADOR, FO.NRORG
		                               FROM FILIOPER FO
		                       JOIN (SELECT CDFILIAL, NRORG
		                               FROM FILIAL
		                              WHERE ((INSTR(:CDFILIAL, CDFILIAL) <> 0) OR (:TCDFILIAL = 'T'))
		                                AND NRORG = :NRORG) F
		                          ON FO.CDFILIAL = F.CDFILIAL
		                         AND FO.NRORG = F.NRORG
		                 WHERE FO.CDOPERADOR = :CDOPERADOR
		               ) F ON B.CDFILIAL = F.CDFILIAL
		         WHERE B.QTESTDIACON <> 0
		           AND B.DTPOSESTCON = (SELECT MAX(P.DTPOSESTCON)
		                                  FROM POSESTCONS P
		                                 WHERE P.CDFILIAL    = B.CDFILIAL
		                                   AND P.CDPRODUTO   = B.CDPRODUTO
		                                   AND P.DTPOSESTCON <= TO_DATE(:DTENTRVENDA) + 1)
		       ) A
		 WHERE VRCUSTO > 0
		 GROUP BY A.CDARVPROD, A.NMPRODUTO
		 ORDER BY 3) B
		WHERE ROWNUM <= 10
	";
	
	const TAB_RNK_MAIOR_CUSTO = "
		SELECT B.CDARVPROD, B.NMPRODUTO, ROUND(B.VRCUSTO,3) AS VRCUSTO
		  FROM (SELECT A.CDARVPROD, A.NMPRODUTO, AVG(VRCUSTO) AS VRCUSTO
		          FROM (SELECT B.CDFILIAL, P.CDARVPROD, P.NMPRODUTO,
		                       NVL(CUSTO_PRODUTO(B.CDFILIAL, B.CDPRODUTO, (SELECT NVL(TO_NUMBER(CDTIPCUSTEST),3)
		                                                                              FROM PARAMFILIAL
		                                                                             WHERE CDFILIAL = B.CDFILIAL), :DTENTRVENDA, SYSDATE),0) AS VRCUSTO
		
		                  FROM POSESTCONS B
		                       JOIN PRODUTO P
		                          ON P.CDPRODUTO = B.CDPRODUTO
		                       JOIN (SELECT FO.CDFILIAL, FO.CDOPERADOR, FO.NRORG
		                               FROM FILIOPER FO
		                       JOIN (SELECT CDFILIAL, NRORG
		                               FROM FILIAL
		                              WHERE ((INSTR(:CDFILIAL , CDFILIAL) <> 0) OR (:TCDFILIAL = 'T'))
		                                AND NRORG = :NRORG) F
		                          ON FO.CDFILIAL = F.CDFILIAL
		                         AND FO.NRORG = F.NRORG
		                 WHERE FO.CDOPERADOR = :CDOPERADOR
		               ) F ON B.CDFILIAL = F.CDFILIAL
		         WHERE B.QTESTDIACON <> 0
		           AND B.DTPOSESTCON = (SELECT MAX(P.DTPOSESTCON)
		                                  FROM POSESTCONS P
		                                 WHERE P.CDFILIAL    = B.CDFILIAL
		                                   AND P.CDPRODUTO   = B.CDPRODUTO
		                                   AND P.DTPOSESTCON <= TO_DATE(:DTENTRVENDA) + 1)
		       ) A
		 WHERE VRCUSTO > 0
		 GROUP BY A.CDARVPROD, A.NMPRODUTO
		 ORDER BY 3 DESC) B
		WHERE ROWNUM <= 10
	";
	
	const TAB_UNIDADES_SEM_CONTAGEM = "
		SELECT 'Unidades sem realizar Contagem nos últimos 7 dias' AS UM,
		       COUNT(*) AS DOIS
		  FROM FILIOPER F
		 WHERE F.CDOPERADOR = :CDOPERADOR
		   AND NOT EXISTS (SELECT I.CDFILIMOVI
		                     FROM ITLANCTOEST I
		                    WHERE I.CDFILIMOVI = F.CDFILIAL
		                      AND I.DTLANCMOVI BETWEEN TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY') - 7 AND :DTENTRVENDA
		                      AND I.IDTIPOMOVI = '1'
		                      AND I.IDEVOLESTOQ = 'S')
		 UNION ALL
		SELECT 'Unidades sem realizar Contagem nos últimos 15 dias' AS UM,
		       COUNT(*) AS DOIS
		  FROM FILIOPER F
		 WHERE F.CDOPERADOR = :CDOPERADOR
		   AND NOT EXISTS (SELECT I.CDFILIMOVI
		                     FROM ITLANCTOEST I
		                    WHERE I.CDFILIMOVI = F.CDFILIAL
		                      AND I.DTLANCMOVI BETWEEN TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY') - 15 AND :DTENTRVENDA
		                      AND I.IDTIPOMOVI = '1'
		                      AND I.IDEVOLESTOQ = 'S')
		
		 UNION ALL
		SELECT 'Unidades sem realizar Contagem nos últimos 30 dias' AS UM,
		       COUNT(*) AS DOIS
		  FROM FILIOPER F
		 WHERE F.CDOPERADOR = :CDOPERADOR
		   AND NOT EXISTS (SELECT I.CDFILIMOVI
		                     FROM ITLANCTOEST I
		                    WHERE I.CDFILIMOVI = F.CDFILIAL
		                      AND I.DTLANCMOVI BETWEEN TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY') - 30 AND :DTENTRVENDA
		                      AND I.IDTIPOMOVI = '1'
		                      AND I.IDEVOLESTOQ = 'S')

	";
	
	const TAB_ULTIMO_AJUSTE = "
		SELECT 'Quantidade de ajustes: '||A.QTDEAJUSTE AS UM, 'Data: '||B.DTULTIMOINVE AS DOIS
		  FROM (SELECT COUNT(DISTINCT I.NRLANCESTQ) AS QTDEAJUSTE
	        	  FROM ITLANCTOEST I, PRODUTO P
	        	 WHERE ((INSTR(:CDFILIAL , I.CDFILIMOVI ) <> 0) OR (:TCDFILIAL = 'T'))
	               AND I.DTLANCMOVI BETWEEN TO_DATE('01/'||TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'MM/YYYY')) AND :DTENTRVENDA
	               AND I.IDTIPOMOVI = '1'
	               AND I.IDEVOLESTOQ = 'S'
	               AND P.CDPRODUTO = I.CDPRODMOVI) A,
	           (SELECT MAX(I.DTLANCMOVI) AS DTULTIMOINVE
	              FROM ITLANCTOEST I, PRODUTO P
	             WHERE ((INSTR(:CDFILIAL , I.CDFILIMOVI ) <> 0) OR (:TCDFILIAL = 'T'))
	               AND I.DTLANCMOVI BETWEEN TO_DATE('01/'||TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'MM/YYYY')) AND :DTENTRVENDA
	               AND I.IDTIPOMOVI = '1'
	               AND I.IDEVOLESTOQ = 'S'
	               AND P.CDPRODUTO = I.CDPRODMOVI) B
	";
	
	const TAB_PROD_MAIS_AJUSTES = "
		SELECT A.CDARVPROD, A.NMPRODUTO, A.SGUNIDADE, A.QTDEAJUSTE
		  FROM (SELECT P.CDARVPROD, P.NMPRODUTO, P.SGUNIDADE, COUNT(*) AS QTDEAJUSTE
		          FROM ITLANCTOEST I
		          JOIN PRODUTO P
		            ON P.CDPRODUTO = I.CDPRODMOVI
		          JOIN (SELECT FO.CDFILIAL, FO.CDOPERADOR, FO.NRORG
		                  FROM FILIOPER FO
		                  JOIN (SELECT CDFILIAL, NRORG
		                          FROM FILIAL
		                         WHERE ((INSTR(:CDFILIAL , CDFILIAL ) <> 0) OR (:TCDFILIAL = 'T'))
		                           AND NRORG = :NRORG
		                       ) F
		                    ON FO.CDFILIAL = F.CDFILIAL
		                   AND FO.NRORG = F.NRORG
		                 WHERE FO.CDOPERADOR = :CDOPERADOR
		               ) F
		            ON I.CDFILIMOVI = F.CDFILIAL
		         WHERE I.DTLANCMOVI BETWEEN TO_DATE('01/'||TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'MM/YYYY')) AND :DTENTRVENDA
		           AND I.IDTIPOMOVI = '1'
		           AND I.IDEVOLESTOQ = 'S'
		         GROUP BY P.CDARVPROD, P.NMPRODUTO, P.SGUNIDADE
		         ORDER BY 4 DESC, P.CDARVPROD) A
		 WHERE ROWNUM <= 10
	";
	
	const  TAB_CONTAS_PAGAR = "
		SELECT SUM(J.VRVENCDIA) AS VRVENCDIA, SUM(J.VRVENC7DIAS) AS VRVENC7DIAS, SUM(J.VRVENC15DIAS) AS VRVENC15DIAS, SUM(J.VRVENC30DIAS) AS VRVENC30DIAS, 
			   SUM(J.VRTOTALVENCIDO) AS VRTOTALVENCIDO, J.CDEMPRESA
		  FROM JOB_FINAN J 
		  JOIN ( SELECT FO.CDFILIAL, FO.CDOPERADOR, FO.NRORG, F.CDEMPRESA
				FROM FILIOPER FO
				JOIN (SELECT CDFILIAL, NRORG, CDEMPRESA
						FROM FILIAL
					   WHERE ((INSTR(:CDFILIAL , CDFILIAL ) <> 0) OR (:TCDFILIAL = 'T'))
						 AND NRORG = :NRORG
					 ) F
				  ON FO.CDFILIAL = F.CDFILIAL
				 AND FO.NRORG = F.NRORG
			   WHERE FO.CDOPERADOR = :CDOPERADOR
			) F
			ON F.CDEMPRESA = J.CDEMPRESA
			AND F.NRORG = J.NRORG
		WHERE  J.IDINFJOB = 'P'
		GROUP BY J.CDEMPRESA
	";
	
	const TAB_CONTAS_RECEBER = "
		SELECT SUM(J.VRVENCDIA) AS VRVENCDIA, SUM(J.VRVENC7DIAS) AS VRVENC7DIAS, SUM(J.VRVENC15DIAS) AS VRVENC15DIAS, SUM(J.VRVENC30DIAS) AS VRVENC30DIAS, 
			   SUM(J.VRTOTALVENCIDO) AS VRTOTALVENCIDO, J.CDEMPRESA
		  FROM JOB_FINAN J 
		  JOIN ( SELECT FO.CDFILIAL, FO.CDOPERADOR, FO.NRORG, F.CDEMPRESA
				FROM FILIOPER FO
				JOIN (SELECT CDFILIAL, NRORG, CDEMPRESA
						FROM FILIAL
					   WHERE ((INSTR(:CDFILIAL , CDFILIAL ) <> 0) OR (:TCDFILIAL = 'T'))
						 AND NRORG = :NRORG
					 ) F
				  ON FO.CDFILIAL = F.CDFILIAL
				 AND FO.NRORG = F.NRORG
			   WHERE FO.CDOPERADOR = :CDOPERADOR
			) F
			ON F.CDEMPRESA = J.CDEMPRESA
			AND F.NRORG = J.NRORG
		WHERE  J.IDINFJOB = 'R'
		GROUP BY J.CDEMPRESA
	";
	
	const TAB_SALDO_EM_CONTA = "
		SELECT SUM(J.VRSALDOCCOR) AS VRSALDO, J.CDEMPRESA, J.DSBANCO AS DESCRICAO
		  FROM JOB_FINAN J 
		  JOIN ( SELECT FO.CDFILIAL, FO.CDOPERADOR, FO.NRORG, F.CDEMPRESA
				FROM FILIOPER FO
				JOIN (SELECT CDFILIAL, NRORG, CDEMPRESA
						FROM FILIAL
					   WHERE ((INSTR(:CDFILIAL , CDFILIAL ) <> 0) OR (:TCDFILIAL = 'T'))
						 AND NRORG = :NRORG
					 ) F
				  ON FO.CDFILIAL = F.CDFILIAL
				 AND FO.NRORG = F.NRORG
			   WHERE FO.CDOPERADOR = :CDOPERADOR
			) F
			ON F.CDEMPRESA = J.CDEMPRESA
			AND F.NRORG = J.NRORG
		WHERE  J.IDINFJOB = 'S'
		GROUP BY J.CDEMPRESA, J.DSBANCO
	";
	
	const TAB_STATUS_NOTA = "
		SELECT 'NF entrada Pendentes' AS LABEL, COUNT(*) QTD
		  FROM NOTAFISCAL N
		  JOIN FILIOPER F
		    ON N.CDFILIAL = F.CDFILIAL
		   AND N.NRORG = F.NRORG
	     WHERE F.CDOPERADOR = :CDOPERADOR
	       AND N.NRORG = :NRORG
	       AND N.IDSTATUS = 'P'
	       AND N.IDSISTEMA = 'DFE'
	       AND N.IDENTRSAIDOP = 'E'
	       AND ((INSTR(:CDFILIAL , N.CDFILIRECE ) <> 0) OR (:TCDFILIAL = 'T'))
	       AND TRUNC(N.DTENTRSAID) BETWEEN TO_DATE('01/'||TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'MM/YYYY')) AND :DTENTRVENDA
    
    	UNION ALL
        
        SELECT 'NF entrada em Digitação' AS LABEL, COUNT(*) QTD
		  FROM NOTAFISCAL N
		  JOIN FILIOPER F
		    ON N.CDFILIAL = F.CDFILIAL
		   AND N.NRORG = F.NRORG
	     WHERE F.CDOPERADOR = :CDOPERADOR
	       AND N.NRORG = :NRORG
	       AND N.IDSTATUS = 'D'
		   AND N.IDSISTEMA = 'DFE'
		   AND N.IDENTRSAIDOP = 'E'
		   AND ((INSTR(:CDFILIAL , N.CDFILIRECE ) <> 0) OR (:TCDFILIAL = 'T'))
		   AND TRUNC(N.DTENTRSAID) BETWEEN TO_DATE('01/'||TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'MM/YYYY')) AND :DTENTRVENDA
    
	    UNION ALL
        
        SELECT 'NF Saida em Digitação' AS LABEL, COUNT(*) QTD
		  FROM NOTAFISCAL N
		  JOIN FILIOPER F
		    ON N.CDFILIAL = F.CDFILIAL
		   AND N.NRORG = F.NRORG
	     WHERE F.CDOPERADOR = :CDOPERADOR
	       AND N.NRORG = :NRORG
	       AND N.IDSTATUS = 'D'
		   AND N.IDSISTEMA = 'DFS'
		   AND N.IDENTRSAIDOP = 'S'
		   AND ((INSTR(:CDFILIAL , N.CDFILIEMIT ) <> 0) OR (:TCDFILIAL = 'T'))
		   AND TRUNC(N.DTENTRSAID) BETWEEN TO_DATE('01/'||TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'MM/YYYY')) AND :DTENTRVENDA
    	
    	UNION ALL   
           
        SELECT 'NF Saida Pendentes' AS LABEL, COUNT(*) QTD
		  FROM NOTAFISCAL N
		  JOIN FILIOPER F
		    ON N.CDFILIAL = F.CDFILIAL
		   AND N.NRORG = F.NRORG
	     WHERE F.CDOPERADOR = :CDOPERADOR
	       AND N.NRORG = :NRORG
	       AND N.IDSTATUS = 'P'
		   AND N.IDSISTEMA = 'DFS'
		   AND N.IDENTRSAIDOP = 'S'
		   AND ((INSTR(:CDFILIAL , N.CDFILIEMIT ) <> 0) OR (:TCDFILIAL = 'T'))
		   AND TRUNC(N.DTENTRSAID) BETWEEN TO_DATE('01/'||TO_CHAR(TO_DATE(:DTENTRVENDA, 'DD/MM/YYYY'), 'MM/YYYY')) AND :DTENTRVENDA
	";
	
	const TAB_CMV = "
		SELECT V.CDFILIAL||' - '||FI.NMFILIAL AS LABELFILIAL, ROUND(NVL(CMVDASHIDEAL, 0 ),2) AS CMVDASHIDEAL, 
			   ROUND(NVL(CMVDASHREDE, 0 ),2) AS CMVDASHREDE, ROUND(NVL(CMVDASHREAL, 0 ),2) AS CMVDASHREAL
		  FROM VNDCARDS V
		  JOIN FILIAL FI
		    ON V.CDFILIAL = FI.CDFILIAL
		    AND V.NRORG = FI.NRORG
		  JOIN FILIOPER FO
		    ON V.CDFILIAL = FO.CDFILIAL
		   AND V.NRORG = FO.NRORG
		   AND FI.CDFILIAL = FO.CDFILIAL
		 WHERE ((INSTR(:CDFILIAL , V.CDFILIAL ) <> 0) OR (:TCDFILIAL = 'T'))
		   AND V.NRORG = :NRORG 
		   AND V.DTVNDCARDS = :DTENTRVENDA 
		   AND FO.CDOPERADOR = :CDOPERADOR
	";

} 